(function () {var enterModule = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.enterModule : undefined;enterModule && enterModule(module);})();var __signature__ = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.default.signature : function (a) {return a;}; /**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/* eslint-disable react/jsx-sort-default-props, react/sort-prop-types */
/* eslint-disable react/forbid-prop-types, react/require-default-props */
import { Component } from 'react';
import PropTypes from 'prop-types';
import MapGL from 'react-map-gl';
import { WebMercatorViewport } from '@math.gl/web-mercator';
import ScatterPlotGlowOverlay from './ScatterPlotGlowOverlay';
import './MapBox.css';import { jsx as _jsx } from "@emotion/react/jsx-runtime";

const NOOP = () => {};
export const DEFAULT_MAX_ZOOM = 16;
export const DEFAULT_POINT_RADIUS = 60;

const propTypes = {
  width: PropTypes.number,
  height: PropTypes.number,
  aggregatorName: PropTypes.string,
  clusterer: PropTypes.object,
  globalOpacity: PropTypes.number,
  hasCustomMetric: PropTypes.bool,
  mapStyle: PropTypes.string,
  mapboxApiKey: PropTypes.string.isRequired,
  onViewportChange: PropTypes.func,
  pointRadius: PropTypes.number,
  pointRadiusUnit: PropTypes.string,
  renderWhileDragging: PropTypes.bool,
  rgb: PropTypes.array,
  bounds: PropTypes.array
};

const defaultProps = {
  width: 400,
  height: 400,
  globalOpacity: 1,
  onViewportChange: NOOP,
  pointRadius: DEFAULT_POINT_RADIUS,
  pointRadiusUnit: 'Pixels'
};

class MapBox extends Component {
  constructor(props) {
    super(props);

    const { width, height, bounds } = this.props;
    // Get a viewport that fits the given bounds, which all marks to be clustered.
    // Derive lat, lon and zoom from this viewport. This is only done on initial
    // render as the bounds don't update as we pan/zoom in the current design.
    const mercator = new WebMercatorViewport({
      width,
      height
    }).fitBounds(bounds);
    const { latitude, longitude, zoom } = mercator;

    this.state = {
      viewport: {
        longitude,
        latitude,
        zoom
      }
    };
    this.handleViewportChange = this.handleViewportChange.bind(this);
  }

  handleViewportChange(viewport) {
    this.setState({ viewport });
    const { onViewportChange } = this.props;
    onViewportChange(viewport);
  }

  render() {
    const {
      width,
      height,
      aggregatorName,
      clusterer,
      globalOpacity,
      mapStyle,
      mapboxApiKey,
      pointRadius,
      pointRadiusUnit,
      renderWhileDragging,
      rgb,
      hasCustomMetric,
      bounds
    } = this.props;
    const { viewport } = this.state;
    const isDragging =
    viewport.isDragging === undefined ? false : viewport.isDragging;

    // Compute the clusters based on the original bounds and current zoom level. Note when zoom/pan
    // to an area outside of the original bounds, no additional queries are made to the backend to
    // retrieve additional data.
    // add this variable to widen the visible area
    const offsetHorizontal = width * 0.5 / 100;
    const offsetVertical = height * 0.5 / 100;
    const bbox = [
    bounds[0][0] - offsetHorizontal,
    bounds[0][1] - offsetVertical,
    bounds[1][0] + offsetHorizontal,
    bounds[1][1] + offsetVertical];

    const clusters = clusterer.getClusters(bbox, Math.round(viewport.zoom));

    return (
      _jsx(MapGL, { ...
        viewport,
        mapStyle: mapStyle,
        width: width,
        height: height,
        mapboxApiAccessToken: mapboxApiKey,
        onViewportChange: this.handleViewportChange,
        preserveDrawingBuffer: true, children:

        _jsx(ScatterPlotGlowOverlay, { ...
          viewport,
          isDragging: isDragging,
          locations: clusters,
          dotRadius: pointRadius,
          pointRadiusUnit: pointRadiusUnit,
          rgb: rgb,
          globalOpacity: globalOpacity,
          compositeOperation: "screen",
          renderWhileDragging: renderWhileDragging,
          aggregation: hasCustomMetric ? aggregatorName : null,
          lngLatAccessor: (location) => {
            const { coordinates } = location.geometry;

            return [coordinates[0], coordinates[1]];
          } }
        ) }
      ));

  } // @ts-ignore
  __reactstandin__regenerateByEval(key, code) {// @ts-ignore
    this[key] = eval(code);}}
MapBox.propTypes = propTypes;
MapBox.defaultProps = defaultProps;const _default =

MapBox;export default _default;;(function () {var reactHotLoader = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.default : undefined;if (!reactHotLoader) {return;}reactHotLoader.register(NOOP, "NOOP", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/legacy-plugin-chart-map-box/src/MapBox.jsx");reactHotLoader.register(DEFAULT_MAX_ZOOM, "DEFAULT_MAX_ZOOM", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/legacy-plugin-chart-map-box/src/MapBox.jsx");reactHotLoader.register(DEFAULT_POINT_RADIUS, "DEFAULT_POINT_RADIUS", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/legacy-plugin-chart-map-box/src/MapBox.jsx");reactHotLoader.register(propTypes, "propTypes", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/legacy-plugin-chart-map-box/src/MapBox.jsx");reactHotLoader.register(defaultProps, "defaultProps", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/legacy-plugin-chart-map-box/src/MapBox.jsx");reactHotLoader.register(MapBox, "MapBox", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/legacy-plugin-chart-map-box/src/MapBox.jsx");reactHotLoader.register(_default, "default", "/Users/evan_1/GitHub/superset/superset-frontend/plugins/legacy-plugin-chart-map-box/src/MapBox.jsx");})();;(function () {var leaveModule = typeof reactHotLoaderGlobal !== 'undefined' ? reactHotLoaderGlobal.leaveModule : undefined;leaveModule && leaveModule(module);})();
//# sourceMappingURL=MapBox.js.map